#[repr(u8)]pub enum Dozeen {
DOZEEN_0 = 0,
DOZEEN_1 = 1,
}Variants
DOZEEN_0 = 0
Doze mode support disabled. AHB clock and serial clock will not be gated off when there is doze mode request from system.
DOZEEN_1 = 1
Doze mode support enabled. AHB clock and serial clock will be gated off when there is doze mode request from system.
Implementations