#[repr(u8)]pub enum Wmopt1 {
WMOPT1_0 = 0,
WMOPT1_1 = 1,
}Variants
WMOPT1_0 = 0
DQS pin will be used as Write Mask when writing to external device. There is no limitation on AHB write burst start address alignment when flash is accessed in individual mode.
WMOPT1_1 = 1
DQS pin will not be used as Write Mask when writing to external device. There is limitation on AHB write burst start address alignment when flash is accessed in individual mode.
Implementations